@@ -17,7 +17,7 @@ from ..core import flatten
 # Modified version of `numpy.lib.function_base._parse_gufunc_signature`
 # Modifications:
 #   - Allow for zero input arguments
-# See http://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
+# See https://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
 _DIMENSION_NAME = r'\w+'
 _CORE_DIMENSION_LIST = '(?:{0:}(?:,{0:})*,?)?'.format(_DIMENSION_NAME)
 _ARGUMENT = r'\({}\)'.format(_CORE_DIMENSION_LIST)
@@ -246,8 +246,8 @@ def apply_gufunc(func, signature, *args, **kwargs):
 
     References
     ----------
-    .. [1] http://docs.scipy.org/doc/numpy/reference/ufuncs.html
-    .. [2] http://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
+    .. [1] https://docs.scipy.org/doc/numpy/reference/ufuncs.html
+    .. [2] https://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
     """
     axes = kwargs.pop("axes", None)
     axis = kwargs.pop("axis", None)
@@ -508,8 +508,8 @@ class gufunc(object):
 
     References
     ----------
-    .. [1] http://docs.scipy.org/doc/numpy/reference/ufuncs.html
-    .. [2] http://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
+    .. [1] https://docs.scipy.org/doc/numpy/reference/ufuncs.html
+    .. [2] https://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
     """
     def __init__(self, pyfunc, **kwargs):
         self.pyfunc = pyfunc
@@ -633,8 +633,8 @@ def as_gufunc(signature=None, **kwargs):
 
     References
     ----------
-    .. [1] http://docs.scipy.org/doc/numpy/reference/ufuncs.html
-    .. [2] http://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
+    .. [1] https://docs.scipy.org/doc/numpy/reference/ufuncs.html
+    .. [2] https://docs.scipy.org/doc/numpy/reference/c-api.generalized-ufuncs.html
     """
     _allowedkeys = {"vectorize", "axes", "axis", "keepdims", "output_sizes", "output_dtypes", "allow_rechunk"}
     if set(_allowedkeys).issubset(kwargs.keys()):
