@@ -9,12 +9,13 @@ from skimage.io import imsave
 
 from dask.utils import tmpdir
 
+
 @contextmanager
 def random_images(n, shape):
     with tmpdir() as dirname:
         for i in range(n):
             fn = os.path.join(dirname, 'image.%d.png' % i)
-            x = np.random.randint(0, 255, size=shape).astype('i1')
+            x = np.random.randint(0, 255, size=shape).astype('u1')
             imsave(fn, x)
 
         yield os.path.join(dirname, '*.png')
@@ -36,7 +37,7 @@ def test_imread_with_custom_function():
         return np.ones((2, 3, 4), dtype='i1')
     with random_images(4, (5, 6, 3)) as globstring:
         im = da_imread(globstring, imread=imread2)
-        assert (im.compute() == np.ones((4, 2, 3, 4), dtype='i1')).all()
+        assert (im.compute() == np.ones((4, 2, 3, 4), dtype='u1')).all()
 
 
 def test_preprocess():
@@ -45,4 +46,4 @@ def test_preprocess():
         return x[:, :, 0]
     with random_images(4, (2, 3, 4)) as globstring:
         im = da_imread(globstring, preprocess=preprocess)
-        assert (im.compute() == np.ones((4, 2, 3), dtype='i1')).all()
+        assert (im.compute() == np.ones((4, 2, 3), dtype='u1')).all()
