@@ -33,6 +33,12 @@ functions = [
     lambda x: x.T,
     lambda x: da.transpose(x, (1, 2, 0)),
     lambda x: x.sum(),
+    lambda x: x.mean(),
+    lambda x: x.moment(order=0),
+    pytest.param(lambda x: x.std(),
+                 marks=pytest.mark.xfail(reason="fixed in https://github.com/pydata/sparse/pull/243")),
+    pytest.param(lambda x: x.var(),
+                 marks=pytest.mark.xfail(reason="fixed in https://github.com/pydata/sparse/pull/243")),
     lambda x: x.dot(np.arange(x.shape[-1])),
     lambda x: x.dot(np.eye(x.shape[-1])),
     lambda x: da.tensordot(x, np.ones(x.shape[:2]), axes=[(0, 1), (0, 1)]),
