@@ -19,7 +19,7 @@ from IPython.display import Image, SVG
 
 
 # Since graphviz doesn't store a graph, we need to parse the output
-label_re = re.compile('.*\[label=(.*?) shape=(.*?)\]')
+label_re = re.compile(r'.*\[label=(.*?) shape=(.*?)\]')
 
 
 def get_label(line):
@@ -76,9 +76,7 @@ def test_to_graphviz():
     g = to_graphviz(dsk)
     labels = list(filter(None, map(get_label, g.body)))
     assert len(labels) == 10        # 10 nodes total
-    funcs = set(('add', 'sum', 'neg'))
-    assert set(labels).difference(dsk) == funcs
-    assert set(labels).difference(funcs) == set(dsk)
+    assert set(labels) == {'c', 'd', 'e', 'f', '""'}
     shapes = list(filter(None, map(get_shape, g.body)))
     assert set(shapes) == set(('box', 'circle'))
 
@@ -89,10 +87,8 @@ def test_to_graphviz_custom():
         data_attributes={'a': {'shape': 'square'}},
         function_attributes={'c': {'label': 'neg_c', 'shape': 'ellipse'}},
     )
-    labels = list(filter(None, map(get_label, g.body)))
-    funcs = set(('add', 'sum', 'neg', 'neg_c'))
-    assert set(labels).difference(dsk) == funcs
-    assert set(labels).difference(funcs) == set(dsk)
+    labels = set(filter(None, map(get_label, g.body)))
+    assert labels == {'neg_c', 'd', 'e', 'f', '""'}
     shapes = list(filter(None, map(get_shape, g.body)))
     assert set(shapes) == set(('box', 'circle', 'square', 'ellipse'))
 
@@ -113,7 +109,7 @@ def test_aliases():
 
 @pytest.mark.parametrize('format,typ', [
     ('png', Image),
-    pytest.mark.xfail(('jpeg', Image), reason='jpeg not always supported in dot'),
+    pytest.param('jpeg', Image, marks=pytest.mark.xfail(reason='jpeg not always supported in dot')),
     ('dot', type(None)),
     ('pdf', type(None)),
     ('svg', SVG),
@@ -137,7 +133,7 @@ def test_dot_graph(tmpdir, format, typ):
 
 @pytest.mark.parametrize('format,typ', [
     ('png', Image),
-    pytest.mark.xfail(('jpeg', Image), reason='jpeg not always supported in dot'),
+    pytest.param('jpeg', Image, marks=pytest.mark.xfail(reason='jpeg not always supported in dot')),
     ('dot', type(None)),
     ('pdf', type(None)),
     ('svg', SVG),
